@@ -3,6 +3,7 @@ from datetime import datetime
 
 from upswingutil.db.model import Status, ReservationGuestInfo, ReservationGuestShort, \
     ReservationModelV2, GuestsModelV2
+from upswingutil.pms import store_reservation_to_alvie
 from upswingutil.resource import get_model_from_cloud_storage
 from upswingutil.pms.rms import NAME, get_key, validate_key
 from upswingutil.db import Mongodb, Firestore, MongodbV2
@@ -31,6 +32,8 @@ def _get_status(status):
         return Status.CONFIRMED
     elif status == 'Pencil':
         return Status.PENCIL
+    elif status == 'Unconfirmed':
+        return Status.UNCONFIRMED
     else:
         logging.error(f'Missing Status : {status}')
         return Status.UNCONFIRMED
@@ -176,22 +179,6 @@ class ReservationSync:
         self.__stay_duration_criteria__ = 10 * 86400
         self.__booking_category_levels__ = ['bronze', 'silver', 'gold', 'platinum']
 
-    def _add_reservation_to_alvie(self, record: ReservationModelV2):
-        try:
-            record = record.to_mongo()
-            for guest in record.get('guestInfo').get('guest_list'):
-                guest = dict(guest)
-                if guest.get('primary'):
-                    docs = self.firestore_db.get_collection(f'Organizations/{record.get("orgId")}/users')\
-                        .where("pmsGuestProfile", "==", guest.get('guest')).stream()
-                    for doc in docs:
-                        self.firestore_db.get_collection(f'Organizations/{record.get("orgId")}/users/{doc.id}/reservations')\
-                            .document(str(record.get('_id'))).set(record, merge=True)
-                        logging.info(f"{record.get('orgId')} : {record.get('_id')} added to {doc.id}")
-        except Exception as e:
-            logging.error(f'Error while storing reservation {record.get("orgId")} : {record.get("_id")} to firestore')
-            logging.error(e)
-
     def _get_booking_type(self, arrival_date: str, created_date: str):
         result = 'unknown'
         try:
@@ -780,7 +767,7 @@ class ReservationSync:
             record = self.transform_reservation(self.extract_reservation_details(record))
             if record:
                 self.mongoV2.save(record)
-                self._add_reservation_to_alvie(record)
+                store_reservation_to_alvie(record)
             else:
                 logging.error(f'Error saving the record {record} as it is None')
 
